@@ -2,17 +2,12 @@
 OpenLink Python Utils - Reusable utilities for caching, data manipulation, parsing, and MongoDB query building
 """
 
-# Import modules only - no function re-exports  
+# Import modules only - no function re-exports
 from . import core
 from . import cache
 from . import query
 
-__version__ = "1.0.1"
+__version__ = "1.0.2"
 __author__ = "OpenLink SpA"
 
-__all__ = [
-    "core",
-    "cache", 
-    "query",
-    "__version__"
-] 
\ No newline at end of file
+__all__ = ["core", "cache", "query", "__version__"]
