@@ -14,7 +14,7 @@ from ..core.parsing import (
     infer_type,
     parse_key_string_to_list,
     parse_list_to_dict,
-    parse_params_to_dict
+    parse_params_to_dict,
 )
 
 
@@ -23,11 +23,11 @@ class QueryBuilder:
     Generic query builder for MongoDB aggregation pipelines.
     Can be used standalone or inherited by CRUD classes.
     """
-    
+
     def __init__(self, collection_prefix: str = "", relations: List = None):
         """
         Initialize the QueryBuilder
-        
+
         Args:
             collection_prefix: Prefix for collection names
             relations: List of relations for lookup operations
@@ -35,23 +35,21 @@ class QueryBuilder:
         self.collection_prefix = collection_prefix
         self.relations = relations or []
 
-
-
     def read_query(
-        self, 
-        db_collection, 
+        self,
+        db_collection,
         params: Union[Dict[str, str], Any] = None,
         query: Optional[Dict[str, Any]] = None,
-        pipeline: Optional[List[Dict[str, Any]]] = None, 
-        pipeline_count: Optional[List[Dict[str, Any]]] = None, 
+        pipeline: Optional[List[Dict[str, Any]]] = None,
+        pipeline_count: Optional[List[Dict[str, Any]]] = None,
         use_cache: bool = False,
-        cache_client = None,
+        cache_client=None,
         cache_key_prefix: str = "",
-        clear_cache: bool = False
+        clear_cache: bool = False,
     ) -> Dict[str, Any]:
         """
         Complete query method that handles parameter parsing and query execution.
-        
+
         Args:
             db_collection: MongoDB collection object
             params: Raw query parameters (will be parsed if provided)
@@ -72,44 +70,26 @@ class QueryBuilder:
             raise ValueError("Either 'params' or 'query' must be provided")
 
         # Handle clear_cache from parsed query
-        if 'clear_cache' in parsed_query:
+        if "clear_cache" in parsed_query:
             clear_cache = parsed_query.pop("clear_cache", False)
 
-        if use_cache and cache_client:
-            # Import cache utilities when needed
-            from ..cache import generate_cache_id, get_or_set_cache, datetime_serializer
-            
-            query_hash = generate_cache_id(parsed_query)
-            id_cache_endpoint = f"{cache_key_prefix}:query:data:{query_hash}"
-
-            return get_or_set_cache(
-                cache_client,
-                id_cache_endpoint,
-                lambda: self.get_query_response(
-                    db_collection, parsed_query, pipeline, pipeline_count, 
-                    cache_client=cache_client, 
-                    cache_key_prefix=cache_key_prefix,
-                    use_cache=True,
-                    clear_cache=clear_cache
-                ),
-                clear_cache=f"{cache_key_prefix}:query:data:*" if clear_cache else False,
-                ttl=60*30,
-                serializer=datetime_serializer
-            )
-        else:
-            return self.get_query_response(
-                db_collection, parsed_query, pipeline, pipeline_count,
-                cache_client=cache_client,
-                cache_key_prefix=cache_key_prefix,
-                use_cache=False,
-                clear_cache=clear_cache
-            )
+        self.get_query_response(
+            db_collection,
+            parsed_query,
+            pipeline,
+            pipeline_count,
+            cache_client=cache_client,
+            cache_key_prefix=cache_key_prefix,
+            use_cache=use_cache,
+            clear_cache=clear_cache,
+        )
 
     def build_filter_pipeline(self, filters: Dict[str, Any]) -> Dict[str, Any]:
         """
         Build a filter pipeline from query filters.
         Supports various operators including text search, comparison, and logical operators.
         """
+
         def get_value_type_and_string(value):
             """Determine value type and return appropriate string representation"""
             if value is None:
@@ -136,78 +116,131 @@ class QueryBuilder:
             """Expand a single text search condition into multiple conditions for different field types"""
             expanded_conditions = []
             escaped_value = re.escape(str_value)
-            
+
             # Condition 1: For string fields - use regex
             match operator:
                 case "$containsi":
-                    expanded_conditions.append({field_name: {"$regex": escaped_value, "$options": "i"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": escaped_value, "$options": "i"}}
+                    )
                 case "$contains":
                     expanded_conditions.append({field_name: {"$regex": escaped_value}})
                 case "$notContainsi":
-                    expanded_conditions.append({field_name: {"$not": {"$regex": escaped_value, "$options": "i"}}})
+                    expanded_conditions.append(
+                        {
+                            field_name: {
+                                "$not": {"$regex": escaped_value, "$options": "i"}
+                            }
+                        }
+                    )
                 case "$notContains":
-                    expanded_conditions.append({field_name: {"$not": {"$regex": escaped_value}}})
+                    expanded_conditions.append(
+                        {field_name: {"$not": {"$regex": escaped_value}}}
+                    )
                 case "$startsWith":
-                    expanded_conditions.append({field_name: {"$regex": f"^{escaped_value}"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": f"^{escaped_value}"}}
+                    )
                 case "$startsWithi":
-                    expanded_conditions.append({field_name: {"$regex": f"^{escaped_value}", "$options": "i"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": f"^{escaped_value}", "$options": "i"}}
+                    )
                 case "$endsWith":
-                    expanded_conditions.append({field_name: {"$regex": f"{escaped_value}$"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": f"{escaped_value}$"}}
+                    )
                 case "$endsWithi":
-                    expanded_conditions.append({field_name: {"$regex": f"{escaped_value}$", "$options": "i"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": f"{escaped_value}$", "$options": "i"}}
+                    )
                 case "$eqi":
-                    expanded_conditions.append({field_name: {"$regex": f"^{escaped_value}$", "$options": "i"}})
+                    expanded_conditions.append(
+                        {field_name: {"$regex": f"^{escaped_value}$", "$options": "i"}}
+                    )
                 case "$nei":
-                    expanded_conditions.append({field_name: {"$not": {"$regex": f"^{escaped_value}$", "$options": "i"}}})
-            
+                    expanded_conditions.append(
+                        {
+                            field_name: {
+                                "$not": {
+                                    "$regex": f"^{escaped_value}$",
+                                    "$options": "i",
+                                }
+                            }
+                        }
+                    )
+
             # Condition 2: For numeric fields - if the search value looks like a number
             if is_numeric_string(str_value):
                 try:
                     # Convert to number for direct numeric comparison
-                    if '.' in str_value:
+                    if "." in str_value:
                         numeric_value = float(str_value)
                     else:
                         numeric_value = int(str_value)
-                    
+
                     match operator:
                         case "$containsi" | "$contains":
                             # Exact numeric match
                             expanded_conditions.append({field_name: numeric_value})
-                            
+
                             # For integer searches, also check decimal equivalents
-                            if str_value == str(int(float(str_value))):  # It's a whole number like "10"
+                            if str_value == str(
+                                int(float(str_value))
+                            ):  # It's a whole number like "10"
                                 int_val = int(float(str_value))
                                 # Add the float version too
                                 expanded_conditions.append({field_name: float(int_val)})
-                                
+
                                 # For single digit or small numbers, add range searches
                                 # to catch things like 10 in 10.5, 100, etc.
                                 if len(str_value) <= 2 and int_val >= 0:
                                     # Range for numbers like 10.x (10.0 to 10.999...)
-                                    expanded_conditions.append({
-                                        field_name: {"$gte": int_val, "$lt": int_val + 1}
-                                    })
-                                    
+                                    expanded_conditions.append(
+                                        {
+                                            field_name: {
+                                                "$gte": int_val,
+                                                "$lt": int_val + 1,
+                                            }
+                                        }
+                                    )
+
                                     # Range for numbers like x10 (10, 110, 210, etc.)
                                     if int_val > 0:
                                         # Numbers that start with this digit
-                                        range_start = int_val * (10 ** (len(str(int_val))))
-                                        range_end = range_start + (10 ** (len(str(int_val)))) - 1
+                                        range_start = int_val * (
+                                            10 ** (len(str(int_val)))
+                                        )
+                                        range_end = (
+                                            range_start
+                                            + (10 ** (len(str(int_val))))
+                                            - 1
+                                        )
                                         if range_start != int_val:  # Avoid duplicate
-                                            expanded_conditions.append({
-                                                field_name: {"$gte": range_start, "$lte": range_end}
-                                            })
-                        
+                                            expanded_conditions.append(
+                                                {
+                                                    field_name: {
+                                                        "$gte": range_start,
+                                                        "$lte": range_end,
+                                                    }
+                                                }
+                                            )
+
                         case "$eqi":
                             expanded_conditions.append({field_name: numeric_value})
                             if isinstance(numeric_value, int):
-                                expanded_conditions.append({field_name: float(numeric_value)})
-                        
+                                expanded_conditions.append(
+                                    {field_name: float(numeric_value)}
+                                )
+
                         case "$nei":
-                            expanded_conditions.append({field_name: {"$ne": numeric_value}})
+                            expanded_conditions.append(
+                                {field_name: {"$ne": numeric_value}}
+                            )
                             if isinstance(numeric_value, int):
-                                expanded_conditions.append({field_name: {"$ne": float(numeric_value)}})
-                        
+                                expanded_conditions.append(
+                                    {field_name: {"$ne": float(numeric_value)}}
+                                )
+
                         case "$startsWith" | "$startsWithi":
                             # Exact match
                             expanded_conditions.append({field_name: numeric_value})
@@ -215,41 +248,58 @@ class QueryBuilder:
                             if str_value == str(int(float(str_value))):
                                 int_val = int(float(str_value))
                                 range_start = int_val * (10 ** (len(str(int_val))))
-                                range_end = range_start + (10 ** (len(str(int_val)))) - 1
+                                range_end = (
+                                    range_start + (10 ** (len(str(int_val)))) - 1
+                                )
                                 if range_start != int_val:
-                                    expanded_conditions.append({
-                                        field_name: {"$gte": range_start, "$lte": range_end}
-                                    })
-                        
+                                    expanded_conditions.append(
+                                        {
+                                            field_name: {
+                                                "$gte": range_start,
+                                                "$lte": range_end,
+                                            }
+                                        }
+                                    )
+
                         case "$endsWith" | "$endsWithi":
                             # For ends with, just exact match for now
                             expanded_conditions.append({field_name: numeric_value})
-                        
+
                 except ValueError:
                     pass
-            
+
             return expanded_conditions
 
         def build_sub_pipeline(conditions, field_name=None):
             sub_pipeline = {}
             for operator, value in conditions.items():
                 value_type, str_value = get_value_type_and_string(value)
-                
+
                 # Text search operators that need special handling for mixed types
-                text_search_ops = ["$contains", "$notContains", "$containsi", "$notContainsi", 
-                                 "$startsWith", "$startsWithi", "$endsWith", "$endsWithi", "$eqi", "$nei"]
-                
+                text_search_ops = [
+                    "$contains",
+                    "$notContains",
+                    "$containsi",
+                    "$notContainsi",
+                    "$startsWith",
+                    "$startsWithi",
+                    "$endsWith",
+                    "$endsWithi",
+                    "$eqi",
+                    "$nei",
+                ]
+
                 if operator in text_search_ops:
                     # For simple field conditions (not in $or), use basic approach
                     escaped_value = re.escape(str_value)
-                    
+
                     if is_numeric_string(str_value):
                         try:
-                            if '.' in str_value:
+                            if "." in str_value:
                                 numeric_value = float(str_value)
                             else:
                                 numeric_value = int(str_value)
-                            
+
                             # For exact match operators, prefer numeric
                             if operator in ["$eqi", "$eq"]:
                                 sub_pipeline = numeric_value
@@ -261,11 +311,17 @@ class QueryBuilder:
                         except ValueError:
                             # Fall back to regex
                             if operator == "$containsi":
-                                sub_pipeline = {"$regex": escaped_value, "$options": "i"}
+                                sub_pipeline = {
+                                    "$regex": escaped_value,
+                                    "$options": "i",
+                                }
                             elif operator == "$contains":
                                 sub_pipeline = {"$regex": escaped_value}
                             else:
-                                sub_pipeline = {"$regex": escaped_value, "$options": "i"}
+                                sub_pipeline = {
+                                    "$regex": escaped_value,
+                                    "$options": "i",
+                                }
                     else:
                         # Non-numeric search, use regex
                         if operator == "$containsi":
@@ -275,15 +331,29 @@ class QueryBuilder:
                         elif operator == "$startsWith":
                             sub_pipeline = {"$regex": f"^{escaped_value}"}
                         elif operator == "$startsWithi":
-                            sub_pipeline = {"$regex": f"^{escaped_value}", "$options": "i"}
+                            sub_pipeline = {
+                                "$regex": f"^{escaped_value}",
+                                "$options": "i",
+                            }
                         elif operator == "$endsWith":
                             sub_pipeline = {"$regex": f"{escaped_value}$"}
                         elif operator == "$endsWithi":
-                            sub_pipeline = {"$regex": f"{escaped_value}$", "$options": "i"}
+                            sub_pipeline = {
+                                "$regex": f"{escaped_value}$",
+                                "$options": "i",
+                            }
                         elif operator == "$eqi":
-                            sub_pipeline = {"$regex": f"^{escaped_value}$", "$options": "i"}
+                            sub_pipeline = {
+                                "$regex": f"^{escaped_value}$",
+                                "$options": "i",
+                            }
                         elif operator == "$nei":
-                            sub_pipeline = {"$not": {"$regex": f"^{escaped_value}$", "$options": "i"}}
+                            sub_pipeline = {
+                                "$not": {
+                                    "$regex": f"^{escaped_value}$",
+                                    "$options": "i",
+                                }
+                            }
                         else:
                             sub_pipeline = {"$regex": escaped_value, "$options": "i"}
                 else:
@@ -323,13 +393,17 @@ class QueryBuilder:
                             sub_pipeline = {"$not": {"$exists": value}}
                         case "$between":
                             if not isinstance(value, list) or len(value) != 2:
-                                raise ValueError(f"$between operator requires an array with exactly 2 elements, got: {value}")
+                                raise ValueError(
+                                    f"$between operator requires an array with exactly 2 elements, got: {value}"
+                                )
                             sub_pipeline = {"$gte": value[0], "$lte": value[1]}
                         case _:
                             if isinstance(value, dict):
                                 sub_pipeline = {
-                                    '_field': operator,
-                                    '_conditions': build_sub_pipeline(value, field_name)
+                                    "_field": operator,
+                                    "_conditions": build_sub_pipeline(
+                                        value, field_name
+                                    ),
                                 }
                             else:
                                 # If it's not a recognized operator, treat as equality
@@ -346,20 +420,32 @@ class QueryBuilder:
                         # Check if this condition contains text search operators
                         field_name = list(condition.keys())[0]
                         field_conditions = condition[field_name]
-                        
+
                         if isinstance(field_conditions, dict):
                             operator = list(field_conditions.keys())[0]
                             value = field_conditions[operator]
-                            
+
                             # Text search operators that need expansion
-                            text_search_ops = ["$contains", "$notContains", "$containsi", "$notContainsi", 
-                                             "$startsWith", "$startsWithi", "$endsWith", "$endsWithi", "$eqi", "$nei"]
-                            
+                            text_search_ops = [
+                                "$contains",
+                                "$notContains",
+                                "$containsi",
+                                "$notContainsi",
+                                "$startsWith",
+                                "$startsWithi",
+                                "$endsWith",
+                                "$endsWithi",
+                                "$eqi",
+                                "$nei",
+                            ]
+
                             if operator in text_search_ops:
                                 # Expand this condition into multiple alternatives
                                 value_type, str_value = get_value_type_and_string(value)
-                                expanded_conditions = expand_text_search_condition(field_name, operator, str_value)
-                                
+                                expanded_conditions = expand_text_search_condition(
+                                    field_name, operator, str_value
+                                )
+
                                 # Add all expanded conditions to the $or
                                 or_conditions.extend(expanded_conditions)
                             else:
@@ -370,7 +456,7 @@ class QueryBuilder:
                             # Regular condition, process normally
                             sub_pipeline = self.build_filter_pipeline(condition)
                             or_conditions.append(sub_pipeline)
-                    
+
                     pipeline["$or"] = or_conditions
                 case "$and":
                     and_conditions = []
@@ -383,9 +469,9 @@ class QueryBuilder:
                         sub_pipeline = build_sub_pipeline(conditions, field)
 
                         if isinstance(sub_pipeline, dict):
-                            if '_field' in sub_pipeline:
+                            if "_field" in sub_pipeline:
                                 new_field = f"{field}.{sub_pipeline['_field']}"
-                                pipeline[new_field] = sub_pipeline['_conditions']
+                                pipeline[new_field] = sub_pipeline["_conditions"]
                                 continue
 
                         pipeline[field] = sub_pipeline
@@ -404,7 +490,9 @@ class QueryBuilder:
             sort_pipeline[field] = 1 if order == "asc" else -1
         return {"$sort": sort_pipeline}
 
-    def build_fields_pipeline(self, fields_params: List[str], populate_params: Optional[List] = None) -> Dict[str, Any]:
+    def build_fields_pipeline(
+        self, fields_params: List[str], populate_params: Optional[List] = None
+    ) -> Dict[str, Any]:
         """Build fields projection pipeline"""
         fields_pipeline = {field: 1 for field in fields_params}
 
@@ -414,7 +502,12 @@ class QueryBuilder:
 
         return {"$project": fields_pipeline}
 
-    def build_distinct_pipeline(self, distinct_params: List[str], include_project: bool = True, pipeline: Optional[List] = None) -> List[Dict[str, Any]]:
+    def build_distinct_pipeline(
+        self,
+        distinct_params: List[str],
+        include_project: bool = True,
+        pipeline: Optional[List] = None,
+    ) -> List[Dict[str, Any]]:
         """Build distinct pipeline"""
         group_id = {field: f"${field}" for field in distinct_params}
         group_stage = {"$group": {"_id": group_id}}
@@ -424,7 +517,9 @@ class QueryBuilder:
         else:
             return [group_stage]
 
-    def build_pagination_pipeline(self, pagination_params: Dict[str, Any], pipeline: Optional[List] = None) -> List[Dict[str, Any]]:
+    def build_pagination_pipeline(
+        self, pagination_params: Dict[str, Any], pipeline: Optional[List] = None
+    ) -> List[Dict[str, Any]]:
         """Build pagination pipeline"""
         pageSize = pagination_params.get("pageSize", 10)
         page = pagination_params.get("page", 1)
@@ -432,26 +527,28 @@ class QueryBuilder:
 
         pipeline_copy = deepcopy(pipeline) if pipeline else []
 
-        has_skip = any('$skip' in stage for stage in pipeline_copy)
-        has_limit = any('$limit' in stage for stage in pipeline_copy)
+        has_skip = any("$skip" in stage for stage in pipeline_copy)
+        has_limit = any("$limit" in stage for stage in pipeline_copy)
 
         if not has_skip:
             pipeline_copy.append({"$skip": skip})
         else:
             for stage in pipeline_copy:
-                if '$skip' in stage:
-                    stage['$skip'] = skip
+                if "$skip" in stage:
+                    stage["$skip"] = skip
 
         if not has_limit:
             pipeline_copy.append({"$limit": pageSize})
         else:
             for stage in pipeline_copy:
-                if '$limit' in stage:
-                    stage['$limit'] = pageSize
+                if "$limit" in stage:
+                    stage["$limit"] = pageSize
 
         return pipeline_copy
 
-    def sanitize_result(self, query: Dict[str, Any], data_result: Any, meta_result: Any) -> Dict[str, Any]:
+    def sanitize_result(
+        self, query: Dict[str, Any], data_result: Any, meta_result: Any
+    ) -> Dict[str, Any]:
         """Sanitize query results"""
         if "distinct" in query:
             if (
@@ -467,14 +564,11 @@ class QueryBuilder:
                 meta_result = meta_result[0]
             else:
                 meta_result = {"totalCount": 0}
-        
+
         if not meta_result or "totalCount" not in meta_result:
             meta_result = {"totalCount": 0}
 
-        return {
-            "data": data_result,
-            "meta": meta_result
-        }
+        return {"data": data_result, "meta": meta_result}
 
     def get_lookup_relation(self, relation_field: List[str]) -> tuple:
         """Get lookup relation configuration for a specific relation field"""
@@ -513,9 +607,7 @@ class QueryBuilder:
                                     "$expr": {
                                         "$eq": [
                                             "$_id",
-                                            {
-                                                "$toObjectId": "$$usersId"
-                                            },
+                                            {"$toObjectId": "$$usersId"},
                                         ]
                                     }
                                 }
@@ -542,13 +634,7 @@ class QueryBuilder:
                                     "establishment_active_id": 0,
                                 }
                             },
-                            {
-                                "$addFields": {
-                                    "_id": {
-                                        "$toString": "$_id"
-                                    }
-                                }
-                            },
+                            {"$addFields": {"_id": {"$toString": "$_id"}}},
                         ],
                         "as": "person",
                     }
@@ -580,7 +666,7 @@ class QueryBuilder:
                         "as": _as,
                     },
                 },
-                {"$unwind": {"path": f"${_as}", "preserveNullAndEmptyArrays": True}}
+                {"$unwind": {"path": f"${_as}", "preserveNullAndEmptyArrays": True}},
             ]
 
         if not "_ids" in relation_field_name:
@@ -613,7 +699,7 @@ class QueryBuilder:
                         lookup_relation = self.get_lookup_relation(relation)
                         query_lookup_relations = [
                             *query_lookup_relations,
-                            *lookup_relation[0]
+                            *lookup_relation[0],
                         ]
         if isinstance(query_relations, dict):
             for query_relation in query_relations.keys():
@@ -630,14 +716,16 @@ class QueryBuilder:
                             lookup_relation = self.get_lookup_relation(relation)
                             query_lookup_relations = [
                                 *query_lookup_relations,
-                                *lookup_relation[0]
+                                *lookup_relation[0],
                             ]
-                        
+
                         if isinstance(query_relations[query_relation], dict):
-                            lookup_relation = self.get_lookup_relation(relation, query_relations[query_relation])
+                            lookup_relation = self.get_lookup_relation(
+                                relation, query_relations[query_relation]
+                            )
                             query_lookup_relations = [
                                 *query_lookup_relations,
-                                *lookup_relation[0]
+                                *lookup_relation[0],
                             ]
         return query_lookup_relations
 
@@ -665,7 +753,7 @@ class QueryBuilder:
         _as = collection_name_relation
         if len(relation_field) > 4 and relation_field[4]:
             _as = relation_field[4]
-        
+
         lookup_relation = [
             {
                 "$lookup": {
@@ -673,25 +761,28 @@ class QueryBuilder:
                     "let": {"lid": f"${relation_field_name}"},
                     "pipeline": [
                         {"$addFields": {"_id": {"$toString": "$_id"}}},
-                        match_stage
+                        match_stage,
                     ],
                     "as": _as,
                 },
             }
         ]
 
-        if not '_ids' in relation_field_name:
+        if not "_ids" in relation_field_name:
             lookup_relation.append(
                 {
-                "$unwind": {
-                    "path": f"${collection_name_relation}",
-                    "preserveNullAndEmptyArrays": True,
+                    "$unwind": {
+                        "path": f"${collection_name_relation}",
+                        "preserveNullAndEmptyArrays": True,
+                    }
                 }
-            })
+            )
 
-        return lookup_relation, collection_name_relation    
+        return lookup_relation, collection_name_relation
 
-    def get_count_lookup_relations(self, query_relations: List[str]) -> List[Dict[str, Any]]:
+    def get_count_lookup_relations(
+        self, query_relations: List[str]
+    ) -> List[Dict[str, Any]]:
         """Get count lookup relations for query population"""
         query_lookup_relations = []
 
@@ -708,7 +799,7 @@ class QueryBuilder:
                     lookup_relation = self.get_count_lookup_relation(relation)
                     query_lookup_relations = [
                         *query_lookup_relations,
-                        *lookup_relation[0]
+                        *lookup_relation[0],
                     ]
 
         return query_lookup_relations
@@ -717,12 +808,11 @@ class QueryBuilder:
         """Build populate pipeline"""
         return self.get_query_lookup_relations(populate_params)
 
-    def make_aggregation_query(self, query: Dict[str, Any], base_pipeline: Optional[List] = None) -> List[Dict[str, Any]]:
+    def make_aggregation_query(
+        self, query: Dict[str, Any], base_pipeline: Optional[List] = None
+    ) -> List[Dict[str, Any]]:
         """Make aggregation query pipeline"""
-        pipeline = (
-            [] if not base_pipeline 
-            else deepcopy(base_pipeline)
-        )
+        pipeline = [] if not base_pipeline else deepcopy(base_pipeline)
 
         if "populate" in query:
             pipeline.extend(self.build_populate_pipeline(query["populate"]))
@@ -731,10 +821,16 @@ class QueryBuilder:
             filter_pipeline = self.build_filter_pipeline(query["filters"])
             pipeline.append({"$match": filter_pipeline})
 
-        if "distinct" in query: 
-            pipeline.extend(self.build_distinct_pipeline(query["distinct"], include_project=True, pipeline=pipeline))
+        if "distinct" in query:
+            pipeline.extend(
+                self.build_distinct_pipeline(
+                    query["distinct"], include_project=True, pipeline=pipeline
+                )
+            )
         elif "fields" in query:
-            pipeline.append(self.build_fields_pipeline(query["fields"], query.get("populate", None)))
+            pipeline.append(
+                self.build_fields_pipeline(query["fields"], query.get("populate", None))
+            )
 
         if "sort" in query:
             pipeline.append(self.build_sort_pipeline(query["sort"]))
@@ -742,33 +838,55 @@ class QueryBuilder:
         pipeline = self.build_pagination_pipeline(query.get("pagination", {}), pipeline)
 
         return pipeline
-    
-    def make_count_aggregation_query(self, query: Dict[str, Any], base_pipeline: Optional[List] = None) -> List[Dict[str, Any]]:
+
+    def make_count_aggregation_query(
+        self, query: Dict[str, Any], base_pipeline: Optional[List] = None
+    ) -> List[Dict[str, Any]]:
         """Make count aggregation query pipeline"""
         pipeline = deepcopy(base_pipeline) if base_pipeline else []
 
         if "filters" in query:
             if not pipeline:
-                lookup_filters = {field: value for field, value in query["filters"].items() if list(value.keys())[0][0] != "$"}
+                lookup_filters = {
+                    field: value
+                    for field, value in query["filters"].items()
+                    if list(value.keys())[0][0] != "$"
+                }
 
                 if list(lookup_filters.keys()):
-                    populate_from_filters = self.get_count_lookup_relations(list(lookup_filters.keys()))
+                    populate_from_filters = self.get_count_lookup_relations(
+                        list(lookup_filters.keys())
+                    )
                     pipeline.extend(populate_from_filters)
 
             filter_pipeline = self.build_filter_pipeline(query["filters"])
             pipeline.append({"$match": filter_pipeline})
-        
+
         if "distinct" in query:
-            pipeline.extend(self.build_distinct_pipeline(query["distinct"], include_project=False, pipeline=pipeline))
+            pipeline.extend(
+                self.build_distinct_pipeline(
+                    query["distinct"], include_project=False, pipeline=pipeline
+                )
+            )
 
         pipeline.append({"$count": "totalCount"})
 
         return pipeline
 
-    def get_query_response(self, db_collection, query: Dict[str, Any], pipeline: Optional[List] = None, pipeline_count: Optional[List] = None, cache_client=None, cache_key_prefix: str = "", use_cache: bool = False, clear_cache: bool = False) -> Dict[str, Any]:
+    def get_query_response(
+        self,
+        db_collection,
+        query: Dict[str, Any],
+        pipeline: Optional[List] = None,
+        pipeline_count: Optional[List] = None,
+        cache_client=None,
+        cache_key_prefix: str = "",
+        use_cache: bool = False,
+        clear_cache: bool = False,
+    ) -> Dict[str, Any]:
         """
         Get query response with optional caching support
-        
+
         Args:
             db_collection: MongoDB collection object
             query: Query parameters
@@ -789,11 +907,15 @@ class QueryBuilder:
             # Get count
             if use_cache and cache_client:
                 # Import cache utilities
-                from ..cache import generate_cache_id, get_or_set_cache, datetime_serializer
-                
+                from ..cache import (
+                    generate_cache_id,
+                    get_or_set_cache,
+                    datetime_serializer,
+                )
+
                 # Prepare cache key for meta (count)
                 query_for_hash = deepcopy(query)
-                query_for_hash.pop('pagination', None)
+                query_for_hash.pop("pagination", None)
                 query_hash = generate_cache_id(query_for_hash)
                 count_key = f"{cache_key_prefix}:query:count:{query_hash}"
 
@@ -802,9 +924,13 @@ class QueryBuilder:
                     cache_client,
                     count_key,
                     lambda: list(db_collection.aggregate(count_pipeline)),
-                    clear_cache=f"{cache_key_prefix}:query:count:*" if clear_cache else False,
-                    ttl=60*30,
-                    serializer=lambda x: datetime_serializer(x[0]) if x else {"totalCount": 0}
+                    clear_cache=(
+                        f"{cache_key_prefix}:query:count:*" if clear_cache else False
+                    ),
+                    ttl=60 * 30,
+                    serializer=lambda x: (
+                        datetime_serializer(x[0]) if x else {"totalCount": 0}
+                    ),
                 )
             else:
                 meta_result = list(db_collection.aggregate(count_pipeline))
